const DEFAULT_SKIP = 0;
const DEFAULT_LIMIT = 10;
const cachePaginatedQueriesFactory = (queries) => queries.reduce((acc, query) => {
    const queryName = typeof query === 'string' ? query : query.name;
    const keyArgs = typeof query === 'string' ? ['criteria', 'sort'] : query.keyArgs;
    const skipKey = typeof query === 'string' ? 'skip' : query.skipKey;
    const limitKey = typeof query === 'string' ? 'limit' : query.limitKey;
    return {
        ...acc,
        [queryName]: {
            keyArgs,
            merge(existing, incoming, { args }) {
                const skip = args.get(skipKey, DEFAULT_SKIP);
                const merged = existing?.data.length > 0 ? existing.data.slice(0) : [];
                incoming?.data.forEach((curr, index) => {
                    merged[skip + index] = curr;
                });
                return { ...incoming, data: merged };
            },
            read(existing, { args }) {
                const skip = args.get(skipKey, DEFAULT_SKIP);
                const limit = args.get(limitKey, DEFAULT_LIMIT);
                const data = existing?.data && existing?.data?.slice(skip, skip + limit);
                return {
                    ...existing,
                    data,
                };
            },
        },
    };
}, {});export{DEFAULT_LIMIT,DEFAULT_SKIP,cachePaginatedQueriesFactory};//# sourceMappingURL=cache-paginated-queries.factory.js.map
